import React, { useEffect, useState, useRef, useCallback } from "react";
import { FaCar, FaTachometerAlt, FaRoad, FaMapMarkerAlt, FaSun } from "react-icons/fa";

export const AnimatedLoader = () => {
  // Safely check for RTL direction from document
  const isRTL = document.documentElement.dir === "rtl";
  const [progress, setProgress] = useState(0);
  const [carBounce, setCarBounce] = useState(0);
  const [showExitAnimation, setShowExitAnimation] = useState(false);
  const [currentFact, setCurrentFact] = useState(0);
  const [carSpeed, setCarSpeed] = useState(80);
  const [showTooltip, setShowTooltip] = useState('');
  const loadingCompleted = useRef(false);
  
  // Fun car facts that rotate during loading
  const carFacts = [
    "The average driver spends 38,000 hours behind the wheel in their lifetime.",
    "The word 'car' comes from the Latin word 'carrus', meaning wheeled vehicle.",
    "Dubai has the world's largest fleet of Rolls Royce limousines at the 7-star Burj Al Arab hotel.",
    "The first cars didn't have steering wheels. Drivers used a lever!",
    "A modern car has about 30,000 parts.",
    "The UAE has one of the highest car ownerships per capita worldwide.",
    "The Ferrari sound is actually trademarked.",
    "The best time to buy a new car is at the end of the month when dealers are trying to hit sales targets.",
    "Dubai holds the record for the largest car dance show with 156 cars.",
    "Cars typically use five quarts of oil, which needs changing every 5,000 miles."
  ];
  
  // Handle car fact rotation
  useEffect(() => {
    // Rotate car facts every 5 seconds
    const factInterval = setInterval(() => {
      setCurrentFact(prev => (prev + 1) % carFacts.length);
      // Randomly adjust car speed for fun
      setCarSpeed(80 + Math.floor(Math.random() * 40));
    }, 5000);
    
    return () => clearInterval(factInterval);
  }, [carFacts.length]);

  useEffect(() => {
    // First, check for immediate loader and get its progress
    const immediateLoader = document.getElementById('immediate-loader');
    const immediateProgressBar = document.getElementById('immediate-progress-bar');
    
    // Start with the progress from immediate loader if it exists
    let startingProgress = 0;
    if (immediateProgressBar) {
      // Extract width percentage from the style
      const widthStyle = immediateProgressBar.style.width;
      if (widthStyle) {
        startingProgress = parseInt(widthStyle, 10) || 0;
      }
    }
    
    // Set our initial progress to match the immediate loader
    if (startingProgress > 0) {
      setProgress(startingProgress);
    }
    
    // Remove the immediate loader after a short delay to create a seamless transition
    setTimeout(() => {
      if (immediateLoader) {
        immediateLoader.style.opacity = "0";
        setTimeout(() => {
          immediateLoader.style.display = "none";
        }, 500); // Matches transition duration
      }
    }, 300);
    
    // Continue the progress animation
    const progressTimer = setInterval(() => {
      setProgress(prevProgress => {
        // Start from wherever the immediate loader left off
        const nextProgress = prevProgress + (Math.random() * 7 + 3);
        
        // When reaching 100%, trigger exit animation after a delay
        if (nextProgress >= 100 && !loadingCompleted.current) {
          loadingCompleted.current = true;
          setTimeout(() => setShowExitAnimation(true), 800);
          return 100;
        }
        return nextProgress > 100 ? 100 : nextProgress;
      });
    }, 200);
    
    // Add more dynamic bounce effect to car - for sporty feel
    const bounceTimer = setInterval(() => {
      setCarBounce(prev => {
        // Create a small random bounce to simulate road vibration for sports car
        if (prev === 0) return -1;
        if (prev === -1) return -0.5;
        return 0;
      });
    }, 150); // Faster bouncing
    
    return () => {
      clearInterval(progressTimer);
      clearInterval(bounceTimer);
    };
  }, []);

  return (
    <div 
      className={`w-full h-full fixed flex flex-col items-center justify-center bg-gradient-to-b from-white to-gray-50 z-50 transition-opacity duration-700 ${showExitAnimation ? 'opacity-0' : 'opacity-100'}`}
      style={{ pointerEvents: showExitAnimation ? 'none' : 'auto' }}
    >
      {/* Actual SVG Logo Image */}
      <div className="relative mb-8 flex items-center justify-center">
        <img 
          src="/logos/pitstop360-logo.svg" 
          alt="PitStop 360 Logo" 
          className="w-[250px] h-[60px] object-contain"
          style={{
            filter: 'drop-shadow(0 2px 6px rgba(26, 116, 239, 0.2))'
          }}
        />
      </div>
      
      {/* Dubai skyline with car animation - ENLARGED */}
      <div className="relative w-80 h-44 mb-8 overflow-hidden rounded-lg shadow-lg">
        {/* Sky gradient background with day-night cycle */}
        <div className="absolute inset-0 bg-gradient-to-b from-blue-300 to-blue-100"
          style={{
            animation: 'skyGradient 30s ease-in-out infinite',
            WebkitAnimation: 'skyGradient 30s ease-in-out infinite'
          }}
        ></div>
        
        {/* Sun/Moon */}
        <div className="absolute w-6 h-6 rounded-full bg-yellow-200 shadow-lg opacity-90"
          style={{
            left: '75%',
            top: '15%',
            boxShadow: '0 0 20px rgba(254, 240, 138, 0.8)',
            animation: 'celestialMove 30s ease-in-out infinite',
            WebkitAnimation: 'celestialMove 30s ease-in-out infinite'
          }}
        ></div>
        
        {/* Clouds */}
        <div className="absolute top-[20%] left-[10%] w-16 h-3 bg-white rounded-full opacity-50"></div>
        <div className="absolute top-[15%] left-[30%] w-12 h-4 bg-white rounded-full opacity-40"></div>
        <div className="absolute top-[25%] left-[60%] w-20 h-4 bg-white rounded-full opacity-30"></div>
        
        {/* Dubai Skyline - NOW TRULY GROUNDED AT ROAD LEVEL */}
        <div className="absolute bottom-[4px] left-0 w-[200%] h-28" 
          style={{
            animation: isRTL ? 'cityScroll 40s linear infinite reverse' : 'cityScroll 40s linear infinite',
            WebkitAnimation: isRTL ? 'cityScroll 40s linear infinite reverse' : 'cityScroll 40s linear infinite',
            MozAnimation: isRTL ? 'cityScroll 40s linear infinite reverse' : 'cityScroll 40s linear infinite',
            OAnimation: isRTL ? 'cityScroll 40s linear infinite reverse' : 'cityScroll 40s linear infinite'
          }}
        >
          {/* First set of buildings with window lighting effect */}
          <div className="absolute bottom-0 left-[2%] w-4 h-12 bg-gray-300 shadow-md">
            {/* Windows that light up at night */}
            <div className="absolute inset-1 grid grid-cols-2 grid-rows-5 gap-[2px]">
              {Array.from({ length: 10 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          <div className="absolute bottom-0 left-[5%] w-5 h-14 bg-gray-200 shadow-md">
            {/* More Windows */}
            <div className="absolute inset-1 grid grid-cols-3 grid-rows-6 gap-[2px]">
              {Array.from({ length: 18 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Burj Khalifa - Dubai's iconic tower - MUCH TALLER */}
          <div className="absolute bottom-0 left-[10%]">
            {/* Spire */}
            <div className="w-1 h-24 bg-blue-400/80"></div>
            {/* Upper tapered part with setbacks */}
            <div className="w-3 h-8 -mt-[26px] ml-[-1px] bg-blue-400/70"></div>
            <div className="w-5 h-6 -mt-[3px] ml-[-2px] bg-blue-300/70"></div>
            <div className="w-7 h-5 -mt-[2px] ml-[-3px] bg-blue-200/70"></div>
            {/* Base */}
            <div className="w-9 h-12 -mt-[2px] ml-[-4px] bg-gradient-to-b from-blue-100 to-gray-200 relative">
              {/* Window pattern */}
              <div className="absolute inset-0 grid grid-cols-4 grid-rows-6 gap-[1px] opacity-50">
                {Array.from({ length: 24 }).map((_, i) => (
                  <div key={i} className="bg-yellow-50 opacity-0" style={{
                    animation: `windowLight 30s ease-in-out infinite ${Math.random() * 1.5}s`,
                    WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 1.5}s`
                  }}></div>
                ))}
              </div>
            </div>
          </div>
          
          {/* More buildings */}
          <div className="absolute bottom-0 left-[18%] w-6 h-10 bg-blue-50 shadow-md">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-3 grid-rows-4 gap-[1px]">
              {Array.from({ length: 12 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Dubai Frame - sunken deeper for better blending */}
          <div className="absolute -bottom-8 left-[25%] w-8 h-20 border-2 border-yellow-400 bg-transparent relative">
            {/* Top horizontal piece */}
            <div className="absolute top-0 left-0 right-0 h-2 bg-yellow-400"></div>
            {/* Bottom horizontal piece */}
            <div className="absolute bottom-0 left-0 right-0 h-2 bg-yellow-400"></div>
          </div>
          
          {/* More modern buildings */}
          <div className="absolute bottom-0 left-[32%] w-4 h-9 bg-blue-100 shadow-md rounded-t-lg">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-2 grid-rows-4 gap-[1px]">
              {Array.from({ length: 8 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Burj Al Arab - sail-shaped hotel */}
          <div className="absolute bottom-0 left-[38%]">
            <div className="w-4 h-12 bg-blue-300 rounded-t-full"></div>
            <div className="absolute bottom-0 left-0 w-1 h-10 bg-white rounded-tl-full"></div>
          </div>
          
          {/* More buildings */}
          <div className="absolute bottom-0 left-[45%] w-4 h-11 bg-gray-300 shadow-md">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-2 grid-rows-5 gap-[1px]">
              {Array.from({ length: 10 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          <div className="absolute bottom-0 left-[50%] w-5 h-7 bg-gray-200 shadow-md">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-2 grid-rows-3 gap-[1px]">
              {Array.from({ length: 6 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Second Burj Khalifa - also taller */}
          <div className="absolute bottom-0 left-[60%]">
            {/* Spire */}
            <div className="w-1 h-24 bg-blue-400/80"></div>
            {/* Upper tapered part with setbacks */}
            <div className="w-3 h-8 -mt-[26px] ml-[-1px] bg-blue-400/70"></div>
            <div className="w-5 h-6 -mt-[3px] ml-[-2px] bg-blue-300/70"></div>
            <div className="w-7 h-5 -mt-[2px] ml-[-3px] bg-blue-200/70"></div>
            {/* Base */}
            <div className="w-9 h-12 -mt-[2px] ml-[-4px] bg-gradient-to-b from-blue-100 to-gray-200 relative">
              {/* Window pattern */}
              <div className="absolute inset-0 grid grid-cols-4 grid-rows-6 gap-[1px] opacity-50">
                {Array.from({ length: 24 }).map((_, i) => (
                  <div key={i} className="bg-yellow-50 opacity-0" style={{
                    animation: `windowLight 30s ease-in-out infinite ${Math.random() * 1.5}s`,
                    WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 1.5}s`
                  }}></div>
                ))}
              </div>
            </div>
          </div>
          
          {/* More buildings */}
          <div className="absolute bottom-0 left-[68%] w-6 h-10 bg-blue-50 shadow-md">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-3 grid-rows-4 gap-[1px]">
              {Array.from({ length: 12 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Second Dubai Frame - matching the first one */}
          <div className="absolute -bottom-8 left-[75%] w-8 h-20 border-2 border-yellow-400 bg-transparent relative">
            {/* Top horizontal piece */}
            <div className="absolute top-0 left-0 right-0 h-2 bg-yellow-400"></div>
            {/* Bottom horizontal piece */}
            <div className="absolute bottom-0 left-0 right-0 h-2 bg-yellow-400"></div>
          </div>
          
          {/* More buildings */}
          <div className="absolute bottom-0 left-[82%] w-4 h-9 bg-blue-100 shadow-md rounded-t-lg">
            {/* Windows */}
            <div className="absolute inset-1 grid grid-cols-2 grid-rows-4 gap-[1px]">
              {Array.from({ length: 8 }).map((_, i) => (
                <div key={i} className="bg-yellow-100 opacity-0" style={{
                  animation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`,
                  WebkitAnimation: `windowLight 30s ease-in-out infinite ${Math.random() * 2}s`
                }}></div>
              ))}
            </div>
          </div>
          
          {/* Second Burj Al Arab */}
          <div className="absolute bottom-0 left-[88%]">
            <div className="w-4 h-12 bg-blue-300 rounded-t-full"></div>
            <div className="absolute bottom-0 left-0 w-1 h-10 bg-white rounded-tl-full"></div>
          </div>
          
          {/* More buildings */}
          <div className="absolute bottom-0 left-[94%] w-4 h-11 bg-gray-300 shadow-md"></div>
        </div>
        
        {/* Road with progress indicator */}
        <div className="absolute bottom-0 w-full h-4 bg-gray-800">
          {/* Road surface texture */}
          <div className="absolute top-0 left-0 w-full h-0.5 bg-gray-600/20"></div>
          
          {/* Road middle line */}
          <div className="absolute top-1/2 left-0 w-full h-0.5 bg-yellow-400/80">
            {/* Dashed segments in the middle line */}
            {Array.from({ length: 10 }).map((_, i) => (
              <div 
                key={i} 
                className="absolute top-0 h-full w-4 bg-gray-800"
                style={{ 
                  left: `${i * 10}%`,
                  animation: `roadMarkMove 2s linear infinite ${i * 0.1}s`
                }}
              />
            ))}
          </div>
          
          {/* Progress indicator track */}
          <div className="absolute -bottom-1 w-full h-1 bg-gray-200 rounded-full overflow-hidden">
            <div 
              className="h-full bg-gradient-to-r from-primary/60 to-primary rounded-full transition-all duration-500 ease-out"
              style={{ width: `${progress}%` }}
            />
          </div>
        </div>
        
        {/* Car with bounce effect - optimized for RTL */}
        <div 
          className="absolute bottom-5"
          style={{
            left: isRTL ? 'auto' : '0',
            right: isRTL ? '0' : 'auto',
            transform: `translateX(${isRTL ? -progress : progress}%) translateY(${carBounce}px) ${isRTL ? 'scaleX(-1)' : ''}`,
            transition: 'transform 0.12s cubic-bezier(0.34, 1.56, 0.64, 1)',
            WebkitTransition: 'transform 0.12s cubic-bezier(0.34, 1.56, 0.64, 1)', 
            MozTransition: 'transform 0.12s cubic-bezier(0.34, 1.56, 0.64, 1)',
            OTransition: 'transform 0.12s cubic-bezier(0.34, 1.56, 0.64, 1)'
          }}
        >
          <div className="relative w-16 h-8">
            {/* Realistic car exhaust smoke */}
            {Array.from({ length: 3 }).map((_, i) => (
              <div 
                key={i}
                className={`absolute bottom-1 ${isRTL ? 'right-1' : 'left-1'} w-1.5 h-1.5 rounded-full bg-gray-300/40`}
                style={{ 
                  animation: `smokeOut 1.2s ease-out infinite ${i * 0.35}s`,
                  filter: 'blur(1px)'
                }}
              />
            ))}
            
            {/* Main car body - realistic sedan in deep blue */}
            <div className="absolute bottom-0 w-16 h-3 bg-blue-700 rounded-sm shadow-md" style={{
              borderTopLeftRadius: '1px',
              borderTopRightRadius: '1px',
              borderBottomLeftRadius: '2px',
              borderBottomRightRadius: '2px',
            }}></div>
            
            {/* Hood section with slight incline */}
            <div className="absolute bottom-3 right-2 w-6 h-0.5 bg-blue-700" style={{
              transform: 'skew(5deg)',
            }}></div>
            
            {/* Trunk section */}
            <div className="absolute bottom-3 left-2 w-5 h-0.5 bg-blue-700" style={{
              transform: 'skew(-5deg)',
            }}></div>
            
            {/* Car cabin - perfectly flat roof */}
            <div className="absolute bottom-3.5 left-4 w-7 h-1.5 bg-blue-700 shadow-md"></div>
            
            {/* Windshield with proper angle */}
            <div className="absolute bottom-3.5 left-7.5 w-2.5 h-1.5 bg-blue-300/70" style={{
              transform: 'skew(20deg)',
            }}></div>
            
            {/* Rear window */}
            <div className="absolute bottom-3.5 left-4 w-2 h-1.5 bg-blue-300/70" style={{
              transform: 'skew(-20deg)',
            }}></div>
            
            {/* Side windows - slightly smaller for better proportion */}
            <div className="absolute bottom-3.2 left-5.5 w-2.5 h-1 bg-blue-200/60"></div>
            
            {/* Door line divider */}
            <div className="absolute bottom-1.5 left-7 h-1.5 w-[1px] bg-blue-900/30"></div>
            
            {/* Headlights */}
            <div className="absolute bottom-1.5 right-0.5 w-1.5 h-0.75 bg-yellow-300/90 rounded-sm"></div>
            
            {/* Taillights */}
            <div className="absolute bottom-1.5 left-0.5 w-1 h-0.75 bg-red-500 rounded-sm"></div>
            
            {/* Door handles - subtle */}
            <div className="absolute bottom-2 left-5 w-0.75 h-0.25 bg-gray-300/90 rounded-full"></div>
            <div className="absolute bottom-2 left-8 w-0.75 h-0.25 bg-gray-300/90 rounded-full"></div>
            
            {/* Front grill */}
            <div className="absolute bottom-1 right-1.5 w-2 h-0.5 bg-gray-800 rounded-sm"></div>
            
            {/* Bottom trim/shadow */}
            <div className="absolute bottom-0 left-0 w-16 h-0.5 bg-black/10 rounded-sm"></div>
            
            {/* Wheels with realistic hubcaps and spinning animation */}
            <div className="absolute -bottom-0.5 left-2 w-3.5 h-3.5">
              {/* Tire */}
              <div className="w-full h-full rounded-full bg-gray-800 flex items-center justify-center">
                {/* Wheel rim */}
                <div className="w-[80%] h-[80%] rounded-full bg-gray-300 flex items-center justify-center overflow-hidden shadow-inner border border-gray-400/50">
                  {/* Hubcap with spoke effect */}
                  <div className="relative w-full h-full">
                    {/* Spokes */}
                    {[...Array(5)].map((_, i) => (
                      <div 
                        key={i} 
                        className="absolute top-1/2 left-1/2 h-[100%] w-[1px] bg-gray-400/80"
                        style={{ 
                          transform: `translate(-50%, -50%) rotate(${i * 36}deg)`,
                        }}
                      />
                    ))}
                    {/* Center cap */}
                    <div className="absolute top-1/2 left-1/2 w-[25%] h-[25%] -translate-x-1/2 -translate-y-1/2 rounded-full bg-gray-500 shadow-sm animate-spin" 
                      style={{ animationDuration: '0.5s' }}
                    />
                  </div>
                </div>
              </div>
            </div>
            <div className="absolute -bottom-0.5 right-2 w-3.5 h-3.5">
              {/* Tire */}
              <div className="w-full h-full rounded-full bg-gray-800 flex items-center justify-center">
                {/* Wheel rim */}
                <div className="w-[80%] h-[80%] rounded-full bg-gray-300 flex items-center justify-center overflow-hidden shadow-inner border border-gray-400/50">
                  {/* Hubcap with spoke effect */}
                  <div className="relative w-full h-full">
                    {/* Spokes */}
                    {[...Array(5)].map((_, i) => (
                      <div 
                        key={i} 
                        className="absolute top-1/2 left-1/2 h-[100%] w-[1px] bg-gray-400/80"
                        style={{ 
                          transform: `translate(-50%, -50%) rotate(${i * 36}deg)`,
                        }}
                      />
                    ))}
                    {/* Center cap */}
                    <div className="absolute top-1/2 left-1/2 w-[25%] h-[25%] -translate-x-1/2 -translate-y-1/2 rounded-full bg-gray-500 shadow-sm animate-spin" 
                      style={{ animationDuration: '0.5s' }}
                    />
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
      
      {/* Interactive stats and facts panel */}
      <div className="w-80 bg-white/90 backdrop-blur-sm rounded-lg shadow-lg p-4 text-gray-800 transition-all duration-300">
        {/* Fun Car Facts */}
        <div className="text-center mb-4">
          <div className="text-sm font-semibold mb-1 text-primary/80">Did You Know?</div>
          <div className="text-xs leading-relaxed px-4 min-h-[40px] flex items-center justify-center">
            {carFacts[currentFact]}
          </div>
        </div>
        
        {/* Interactive Stats */}
        <div className="grid grid-cols-3 gap-3 text-xs">
          {/* Speed Indicator */}
          <div 
            className="flex flex-col items-center justify-center bg-gray-50 p-2 rounded relative cursor-pointer transition-all hover:bg-gray-100"
            onMouseEnter={() => setShowTooltip('speed')}
            onMouseLeave={() => setShowTooltip('')}
          >
            <FaTachometerAlt className="text-primary mb-1" />
            <div className="font-medium">{carSpeed} km/h</div>
            {showTooltip === 'speed' && (
              <div className="absolute -top-10 left-0 right-0 bg-black/80 text-white p-1 rounded text-[10px] z-10">
                Virtual Speed
              </div>
            )}
          </div>
          
          {/* Progress */}
          <div 
            className="flex flex-col items-center justify-center bg-gray-50 p-2 rounded relative cursor-pointer transition-all hover:bg-gray-100"
            onMouseEnter={() => setShowTooltip('progress')}
            onMouseLeave={() => setShowTooltip('')}  
          >
            <FaRoad className="text-primary mb-1" />
            <div className="font-medium">{Math.round(progress)}%</div>
            {showTooltip === 'progress' && (
              <div className="absolute -top-10 left-0 right-0 bg-black/80 text-white p-1 rounded text-[10px] z-10">
                Loading Progress
              </div>
            )}
          </div>
          
          {/* Weather */}
          <div 
            className="flex flex-col items-center justify-center bg-gray-50 p-2 rounded relative cursor-pointer transition-all hover:bg-gray-100"
            onMouseEnter={() => setShowTooltip('weather')}
            onMouseLeave={() => setShowTooltip('')}
          >
            <FaSun className="text-yellow-500 mb-1" />
            <div className="font-medium">30°C</div>
            {showTooltip === 'weather' && (
              <div className="absolute -top-10 left-0 right-0 bg-black/80 text-white p-1 rounded text-[10px] z-10">
                Dubai Weather
              </div>
            )}
          </div>
        </div>
      </div>
      
      {/* Animation styles are in tailwind.css */}
    </div>
  );
};